# RedBoard+ PICO 

Python Library to control a RedBoard+ via I2C using a
Raspberry Pi PICO as an I2C secondary device.
Up to four RedBoard+/Pico combinations can be connected
together to control 8 DC motors and 48 servos.
